@@ -1,6 +1,6 @@
 #!/usr/bin/python3
 
-# Copyright (C) 2019-2021 Benjamin Drung <bdrung@posteo.de>
+# Copyright (C) 2019-2022 Benjamin Drung <bdrung@posteo.de>
 #
 # Permission to use, copy, modify, and/or distribute this software for any
 # purpose with or without fee is hereby granted, provided that the above
@@ -50,6 +50,7 @@ MMDEBSTRAP_OPTS = {
     "customize-hooks": list,
     "dpkgopts": list,
     "essential-hooks": list,
+    "format": str,
     "hostname": str,
     "install-recommends": bool,
     "keyrings": list,
@@ -88,6 +89,8 @@ class Mmdebstrap:
             cmd.append(f"--variant={mmdebstrap['variant']}")
         if "mode" in mmdebstrap:
             cmd.append(f"--mode={mmdebstrap['mode']}")
+        if "format" in mmdebstrap:
+            cmd.append(f"--format={mmdebstrap['format']}")
         if "aptopts" in mmdebstrap:
             cmd += [f"--aptopt={aptopt}" for aptopt in mmdebstrap["aptopts"]]
         if "keyrings" in mmdebstrap:
@@ -301,6 +304,11 @@ def parse_args(args):  # pylint: disable=too-many-statements
             "ownership information different from the current user."
         ),
     )
+    parser.add_argument(
+        "--format",
+        choices=["auto", "directory", "dir", "tar", "squashfs", "sqfs", "ext2", "null"],
+        help="Choose the output format.",
+    )
     parser.add_argument(
         "--aptopt", action="append", help="Pass arbitrary options or configuration files to apt."
     )
@@ -558,6 +566,8 @@ class Config(dict):
             self._set_mmdebstrap_option("variant", args.variant)
         if args.mode:
             self._set_mmdebstrap_option("mode", args.mode)
+        if args.format:
+            self._set_mmdebstrap_option("format", args.format)
         if args.aptopt:
             self._append_mmdebstrap_option("aptopts", args.aptopt)
         if args.keyring:
@@ -720,7 +730,7 @@ def prepare_output_dir(output_dir, force, simulate=False):
                         os.remove(path)
         else:
             logger.error(
-                "The output directory '%s' already exist and is not empty. "
+                "The output directory '%s' already exists and is not empty. "
                 "Use --force to remove it.",
                 output_dir,
             )
